@@ -1,8 +1,10 @@
 #!/bin/python
 # -*- coding: utf-8 -*-
+import dill
+from sys import platform
 
 
-def serializer(func):
+def serializer_unix(func):
     """Dirty hack that transforms the non-serializable function to a serializable one (when using dill)
     ...
     Don't try that at home!
@@ -17,6 +19,22 @@ def serializer(func):
     return vodoo
 
 
+def serializer(*functions):
+    """Serialize functions to use multiprocessing"""
+
+    if platform == "darwin" or platform == "linux":
+        rtn = []
+        for func in functions:
+            rtn.append(serializer_unix(func))
+    else:
+        fstr = dill.dumps(functions, recurse=True)
+        rtn = dill.loads(fstr)
+    if len(functions) == 1:
+        return rtn[0]
+    else:
+        return rtn
+
+
 class JoblibPoolDummy(object):
     """joblib Parallel workers pool pretending to behave like a multiprocessing pool"""
 
